@@ -20,7 +20,7 @@ import (
 	"reflect"
 
 	pvdr "github.com/fusor/mig-controller/pkg/cloudprovider"
-	velero "github.com/heptio/velero/pkg/apis/velero/v1"
+	velero "github.com/vmware-tanzu/velero/pkg/apis/velero/v1"
 	kapi "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	k8sclient "sigs.k8s.io/controller-runtime/pkg/client"
@@ -92,6 +92,7 @@ type BackupStorageConfig struct {
 	AzureStorageContainer string                `json:"azureStorageContainer,omitempty"`
 	AzureResourceGroup    string                `json:"azureResourceGroup,omitempty"`
 	GcpBucket             string                `json:"gcpBucket,omitempty"`
+	Insecure              bool                  `json:"insecure"`
 }
 
 func init() {
@@ -231,6 +232,7 @@ func (r *BackupStorageConfig) GetProvider(name string) pvdr.Provider {
 			SignatureVersion: r.AwsSignatureVersion,
 			S3ForcePathStyle: r.AwsS3ForcePathStyle,
 			CustomCABundle:   r.S3CustomCABundle,
+			Insecure:         r.Insecure,
 		}
 	case Azure:
 		provider = &pvdr.AzureProvider{
