@@ -2,7 +2,9 @@ package cloudprovider
 
 import (
 	"bytes"
+	"crypto/tls"
 	"fmt"
+	"net/http"
 	"net/url"
 
 	"github.com/google/uuid"
@@ -16,8 +18,8 @@ import (
 	"github.com/aws/aws-sdk-go/service/ec2"
 	"github.com/aws/aws-sdk-go/service/s3"
 	"github.com/aws/aws-sdk-go/service/s3/s3manager"
-	velero "github.com/heptio/velero/pkg/apis/velero/v1"
 	appsv1 "github.com/openshift/api/apps/v1"
+	velero "github.com/vmware-tanzu/velero/pkg/apis/velero/v1"
 	kapi "k8s.io/api/core/v1"
 )
 
@@ -52,6 +54,7 @@ type AWSProvider struct {
 	S3ForcePathStyle        bool
 	CustomCABundle          []byte
 	SnapshotCreationTimeout string
+	Insecure                bool
 }
 
 func (p *AWSProvider) GetURL() string {
@@ -81,8 +84,9 @@ func (p *AWSProvider) UpdateBSL(bsl *velero.BackupStorageLocation) {
 		},
 	}
 	bsl.Spec.Config = map[string]string{
-		"s3ForcePathStyle": strconv.FormatBool(p.GetForcePathStyle()),
-		"region":           p.GetRegion(),
+		"s3ForcePathStyle":      strconv.FormatBool(p.GetForcePathStyle()),
+		"region":                p.GetRegion(),
+		"insecureSkipTLSVerify": strconv.FormatBool(p.Insecure),
 	}
 	if p.S3URL != "" {
 		bsl.Spec.Config["s3Url"] = p.S3URL
@@ -172,6 +176,10 @@ func (p *AWSProvider) UpdateRegistryDC(dc *appsv1.DeploymentConfig, name, dirNam
 				},
 			},
 		},
+		{
+			Name:  "REGISTRY_STORAGE_S3_SKIPVERIFY",
+			Value: strconv.FormatBool(p.Insecure),
+		},
 	}
 }
 
@@ -279,6 +287,7 @@ func (p *AWSProvider) Test(secret *kapi.Secret) error {
 			bucket:         p.Bucket,
 			secret:         secret,
 			customCABundle: p.CustomCABundle,
+			insecure:       p.Insecure,
 		}
 		err = test.Run()
 	case VolumeSnapshot:
@@ -304,6 +313,7 @@ type S3Test struct {
 	forcePathStyle bool
 	customCABundle []byte
 	secret         *kapi.Secret
+	insecure       bool
 }
 
 func (r *S3Test) Run() error {
@@ -325,8 +335,13 @@ func (r *S3Test) Run() error {
 }
 
 func (r *S3Test) newSession() (*session.Session, error) {
+	transport := &http.Transport{
+		TLSClientConfig: &tls.Config{InsecureSkipVerify: r.insecure},
+	}
+	client := &http.Client{Transport: transport}
 	sessionOptions := session.Options{
 		Config: aws.Config{
+			HTTPClient:       client,
 			Region:           &r.region,
 			Endpoint:         &r.url,
 			DisableSSL:       aws.Bool(r.disableSSL),
