@@ -4,7 +4,7 @@ import (
 	"context"
 	"errors"
 	migapi "github.com/fusor/mig-controller/pkg/apis/migration/v1alpha1"
-	velero "github.com/heptio/velero/pkg/apis/velero/v1"
+	velero "github.com/vmware-tanzu/velero/pkg/apis/velero/v1"
 	kapi "k8s.io/api/core/v1"
 	k8sclient "sigs.k8s.io/controller-runtime/pkg/client"
 )
